@@ -112,6 +112,7 @@ True
 
 """
 
-__version__ = '0.0.3'
+__version__ = '0.0.4'
 
-from ._py import *  # noqa: F401, F403
+from .inplace import Memory  # noqa F401
+from .inplace import collapse_blocks  # noqa F401
